<?php

declare(strict_types = 1);

namespace Drupal\file_extractor\Event;

use Drupal\file\FileInterface;
use Symfony\Component\EventDispatcher\Event;

/**
 * Defines an event to decide if a file entity is indexable.
 */
class FileIndexableEvent extends Event {

  const EVENT_NAME = 'file_extractor.file_indexable';

  /**
   * The file entity.
   *
   * @var \Drupal\file\FileInterface
   */
  protected $file;

  /**
   * If the file is indexable.
   *
   * @var bool
   */
  protected $indexable = TRUE;

  /**
   * FileIndexableEvent constructor.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file being manipulated.
   */
  public function __construct(FileInterface $file) {
    $this->file = $file;
  }

  /**
   * Returns the file entity.
   *
   * @return \Drupal\Core\Entity\EntityInterface
   *   The entity being manipulated.
   */
  public function getFile() {
    return $this->file;
  }

  // phpcs:disable
  /**
   * If the file is indexable or not.
   *
   * @return bool
   *   If the file is indexable or not.
   *
   * @deprecated in 2.0.1 and will be removed in 3.0.0. Use isIndexable()
   *   instead.
   *
   * @SuppressWarnings(PHPMD.ErrorControlOperator)
   * @SuppressWarnings(PHPMD.BooleanGetMethodName)
   */
  public function getIndexable() {
    @trigger_error(__METHOD__ . '() is deprecated in 2.0.1 and will be removed in 3.0.0. use isIndexable() instead.', \E_USER_DEPRECATED);
    return $this->isIndexable();
  }
  // phpcs:enable

  /**
   * If the file is indexable or not.
   *
   * @return bool
   *   If the file is indexable or not.
   */
  public function isIndexable() {
    return $this->indexable;
  }

  /**
   * Indicate if the file is indexable or not.
   *
   * @param bool $indexable
   *   If the file is indexable or not.
   */
  public function setIndexable(bool $indexable) {
    $this->indexable = $indexable;
  }

}
