<?php

declare(strict_types = 1);

namespace Drupal\file_extractor\HookHandler;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\KeyValueStore\KeyValueFactoryInterface;
use Drupal\file\FileInterface;
use Drupal\file_extractor\Form\SettingsForm;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Hook handler related to cache.
 */
class CacheHandler implements ContainerInjectionInterface {

  /**
   * Name of the key value collection.
   */
  const KEY_VALUE_COLLECTION = 'file_extractor';

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Key value service.
   *
   * @var \Drupal\Core\KeyValueStore\KeyValueFactoryInterface
   */
  protected $keyValue;

  /**
   * CacheHandler constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   * @param \Drupal\Core\KeyValueStore\KeyValueFactoryInterface $key_value
   *   Key value service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    KeyValueFactoryInterface $key_value
  ) {
    $this->configFactory = $config_factory;
    $this->keyValue = $key_value;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('keyvalue')
    );
  }

  /**
   * Implements hook_cache_flush().
   */
  public function hookCacheFlush() : void {
    $preserve_cache = $this->configFactory->get(SettingsForm::CONFIG_NAME)->get('preserve_cache');
    if (!$preserve_cache) {
      $this->keyValue->get(self::KEY_VALUE_COLLECTION)->deleteAll();
    }
  }

  /**
   * Helper function to delete a file extracted data cache.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file entity.
   */
  public function deleteFileCache(FileInterface $file) {
    $this->keyValue->get(self::KEY_VALUE_COLLECTION)->delete($file->id());
  }

}
