<?php

declare(strict_types = 1);

namespace Drupal\file_extractor\Service;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\file\FileInterface;

/**
 * Provides helper methods to manipulating test files.
 *
 * @package Drupal\file_extractor\Service
 */
class TestFileHelper implements TestFileHelperInterface {

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * File system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * The test file.
   *
   * @var \Drupal\file\FileInterface
   */
  protected $testFile;

  /**
   * TestFileHelper constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system service.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    FileSystemInterface $file_system
  ) {
    $this->entityTypeManager = $entity_type_manager;
    $this->fileSystem = $file_system;
  }

  /**
   * {@inheritdoc}
   */
  public function getTestFile() : FileInterface {
    if (!isset($this->testFile)) {
      // Copy the source file to public directory.
      $source = drupal_get_path('module', 'file_extractor');
      $source .= '/data/' . self::TEST_FILENAME;
      $this->fileSystem->copy($source, self::TEST_FILE_URI, FileSystemInterface::EXISTS_REPLACE);

      /** @var \Drupal\file\FileInterface $file */
      $this->testFile = $this->entityTypeManager->getStorage('file')->create([
        'filename' => self::TEST_FILENAME,
        'filemime' => 'application/pdf',
        'uri' => self::TEST_FILE_URI,
      ]);
    }

    return $this->testFile;
  }

  /**
   * {@inheritdoc}
   */
  public function deleteTestFile(): void {
    $this->fileSystem->delete(self::TEST_FILE_URI);
    $this->testFile = NULL;
  }

}
